@@ -34,10 +34,18 @@
 
 #define CONTROL(c) ((c) & 0x1f)
 
+#ifndef ESC
+#define ESC (27)
+#endif
+
+#ifndef DEL
+#define DEL (127)
+#endif
+
 /* Supported actions */
 enum action {
 	SEL_BACK = 1,
-	SEL_GOIN,
+	SEL_OPEN,
 	SEL_NAV_IN,
 	SEL_NEXT,
 	SEL_PREV,
@@ -103,10 +111,7 @@ enum action {
 	SEL_QUITCTX,
 	SEL_QUITCD,
 	SEL_QUIT,
-	SEL_QUITFAIL,
-#ifndef NOFIFO
-	SEL_FIFO,
-#endif
+	SEL_QUITERR,
 #ifndef NOMOUSE
 	SEL_CLICK,
 #endif
@@ -123,8 +128,8 @@ static struct key bindings[] = {
 	{ KEY_LEFT,       SEL_BACK },
 	{ 'h',            SEL_BACK },
 	/* Inside or select */
-	{ KEY_ENTER,      SEL_GOIN },
-	{ '\r',           SEL_GOIN },
+	{ KEY_ENTER,      SEL_OPEN },
+	{ '\r',           SEL_OPEN },
 	/* Pure navigate inside */
 	{ KEY_RIGHT,      SEL_NAV_IN },
 	{ 'l',            SEL_NAV_IN },
@@ -207,7 +212,7 @@ static struct key bindings[] = {
 	{ ' ',            SEL_SEL },
 	/* Toggle select multiple files */
 	{ 'm',            SEL_SELMUL },
-	{ CONTROL('K'),   SEL_SELMUL },
+	{ CONTROL(' '),   SEL_SELMUL },
 	/* Select all files in current dir */
 	{ 'a',            SEL_SELALL },
 	/* List, edit selection */
@@ -265,11 +270,7 @@ static struct key bindings[] = {
 	/* Quit */
 	{ CONTROL('Q'),   SEL_QUIT },
 	/* Quit with an error code */
-	{ 'Q',            SEL_QUITFAIL },
-#ifndef NOFIFO
-	/* Send hovered path to NNN_FIFO */
-	{ 27,            SEL_FIFO },
-#endif
+	{ 'Q',            SEL_QUITERR },
 #ifndef NOMOUSE
 	{ KEY_MOUSE,      SEL_CLICK },
 #endif
